@@ -468,16 +468,21 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                 if (button) {
                     // in ios/android buttons do not necessarily get focus when clicked
                     // so we need to do it manually
-                    let os = qx.core.Environment.get('os.name');
-                    if (os == 'android' || os == 'ios'){
-                        let orig_action = action;
-                        action = () => {
+                    //let os = qx.core.Environment.get('os.name');
+                    //if (os == 'android' || os == 'ios'){
+                        // let orig_action = action;
+                        // action = () => {
+                        //     if (button.isFocusable()) {
+                        //         button.focus();
+                        //     }
+                        //     setTimeout(orig_action.bind(this),1);
+                        // }
+                        button.addListener('touchstart', () => { 
                             if (button.isFocusable()) {
-                                button.focus();
+                               button.focus();
                             }
-                            setTimeout(orig_action.bind(this),1);
-                        }
-                    }        
+                        }, this );
+                    //}        
                     button.addListener('execute', action, this);
                     if (btCfg.addToMenu) {
                         menues[btCfg.addToMenu].add(button);
